Learn R Programming

mlxR (version 3.3.0)

mlxplore: Explore and visualize models

Description

Explore and visualize Mlxtran and pharmML models with the Mlxplore software.

Usage

mlxplore(model, parameter = NULL, output = NULL, group = NULL,
  treatment = NULL)

Arguments

model

a Mlxtran or PharmML model

parameter

a vector of parameters with their names and values

output

a list with fields:

  • name: a vector of output names

  • time: a vector of times

group

a list with unique field:

  • treatment : a list,

treatment

a list with fields

  • time : a vector of input times,

  • amount : a scalar or a vector of amounts,

  • rate : a scalar or a vector of infusion rates (default=Inf),

  • type : the type of input (default=1),

  • target : the target compartment (default=NULL).

Details

See http://simulx.webpopix.org/mlxr/mlxplore/ for more details.