Learn R Programming

mlxR (version 3.3.0)

simpopmlx: Population parameters simulation

Description

Draw population parameters using the covariance matrix of the estimates

Usage

simpopmlx(n = 1, project = NULL, fim = "needed", parameter = NULL,
  corr = NULL, kw.max = 100)

Arguments

n

the number of vectors of population parameters (default = 1),

project

a Monolix project, assuming that the Fisher information Matrix was estimated by Monolix.

fim

the Fisher Information Matrix estimated by Monolix. fim="sa", "lin" (default="sa")

parameter

a data frame with a column pop.param (no default), a column sd (no default), and possibly a column trans (default ='N'). Only when project is not used.

corr

correlation matrix of the population parameters (default = identity). Only when project is not used.

kw.max

maximum number of trials for generating a positive definite covariance matrix (default = 100)

Details

See http://simulx.webpopix.org/mlxr/simpopmlx/ for more details.

Examples

Run this code
# NOT RUN {
project.file <- 'monolixRuns/theophylline1_project.mlxtran'  #relative path
pop1 <- simpopmlx(n=3, project=project.file)
# }

Run the code above in your browser using DataLab