Explore and visualize Mlxtran and pharmML models with the Mlxplore software.
mlxplore(model, parameter = NULL, output = NULL, group = NULL,
treatment = NULL)a Mlxtran or PharmML model
a vector of parameters with their names and values
a list with fields:
name: a vector of output names
time: a vector of times
a list with unique field:
treatment : a list,
a list with fields
time : a vector of input times,
amount : a scalar or a vector of amounts,
rate : a scalar or a vector of infusion rates (default=Inf),
type : the type of input (default=1),
target : the target compartment (default=NULL).
See http://simulx.webpopix.org/mlxr/mlxplore/ for more details.